@@ -105,6 +105,9 @@ class NeteaseProvider(AbstractProvider, ProviderV2):
                 for song_data in songs_data]
 
     def rec_list_daily_playlists(self):
+        if not self.has_current_user():
+            return []
+
         playlists_data = self.api.get_recommend_playlists()
         rec_playlists = []
         for playlist_data in playlists_data:
@@ -327,7 +330,7 @@ class NeteaseProvider(AbstractProvider, ProviderV2):
             while offset < count:
                 data = self.api.artist_songs(artist.identifier, offset, per)
                 for song_data in data['songs']:
-                    yield _deserialize(song_data, V2SongSchema)
+                    yield _deserialize(song_data, V2SongSchemaForV3)
                     # In reality, len(data['songs']) may smaller than per,
                     # which is a bug of netease server side, so we set
                     # offset to `offset + per` here.
